@@ -16,7 +16,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
@@ -81,6 +81,14 @@ has 'store' => (
 );
 
 
+has 'nocolor' => (
+    is       => 'ro',
+    isa      => Bool,
+    key      => 'nocolor',
+    default  => 0,
+);
+
+
 has 'nocommit' => (
     is       => 'ro',
     isa      => Bool,
@@ -186,7 +194,7 @@ Pinto::Config - User configuration for Pinto
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 DESCRIPTION
 
