@@ -4,7 +4,7 @@ package Pinto::Logger;
 
 use Moose;
 
-use MooseX::Types::Moose qw(Int);
+use MooseX::Types::Moose qw(Int Bool);
 use Pinto::Types qw(IO);
 
 use Readonly;
@@ -13,7 +13,7 @@ use namespace::autoclean;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 #-----------------------------------------------------------------------------
 # Moose attributes
@@ -31,6 +31,12 @@ has out => (
     default  => sub { [fileno(STDOUT), '>'] },
 );
 
+has colorize => (
+    is         => 'ro',
+    isa        => Bool,
+    lazy_build => 1,
+);
+
 #-----------------------------------------------------------------------------
 # Moose roles
 
@@ -53,6 +59,14 @@ sub _build_log_level {
     return $self->config->verbose();
 }
 
+#-----------------------------------------------------------------------------
+
+sub _build_colorize {
+    my ($self) = @_;
+
+    return not $self->config->nocolor();
+}
+
 #-----------------------------------------------------------------------------
 # Private functions
 
@@ -91,6 +105,7 @@ sub info {
 sub whine {
     my ($self, $message) = @_;
 
+    $message = _colorize($message, 'bold yellow') if $self->colorize();
     $self->_logit($message) if $self->log_level() >= $LOG_LEVEL_WARN;
 
     return 1;
@@ -102,11 +117,33 @@ sub whine {
 sub fatal {
     my ($self, $message) = @_;
 
+    $message = _colorize($message, 'bold red') if $self->colorize();
     die "$message\n";  ## no critic (RequireCarping)
 }
 
 #-----------------------------------------------------------------------------
 
+sub _colorize {
+    my ($string, $color) = @_;
+
+    return $string if not defined $color;
+    return $string if $color eq q{};
+
+    eval { require Term::ANSIColor }
+      or return $string;
+
+    # $terminator is a purely cosmetic change to make the color end at the end
+    # of the line rather than right before the next line. It is here because
+    # if you use background colors, some console windows display a little
+    # fragment of colored background before the next uncolored (or
+    # differently-colored) line.
+
+    my $terminator = chomp $string ? "\n" : q{};
+    return  Term::ANSIColor::colored( $string, $color ) . $terminator;
+}
+
+#-----------------------------------------------------------------------------
+
 __PACKAGE__->meta->make_immutable();
 
 #-----------------------------------------------------------------------------
@@ -125,7 +162,7 @@ Pinto::Logger - A simple logger
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 METHODS
 
